def xyxy_to_yolo_str(x1, y1, x2, y2, img_width, img_height, obj_class):
    # Tọa độ trung tâm
    x_center = (x1 + x2) / 2 / img_width
    y_center = (y1 + y2) / 2 / img_height
    # Chiều rộng và chiều cao
    width = (x2 - x1) / img_width
    height = (y2 - y1) / img_height

    # Tạo chuỗi YOLO: "class x_center y_center width height"
    yolo_str = f"{obj_class} {x_center:.6f} {y_center:.6f} {width:.6f} {height:.6f}"

    return yolo_str


def yolo_str_to_xyxy(yolo_str, img_width, img_height):
    # Tách chuỗi YOLO thành các giá trị
    yolo_data = yolo_str.split()
    obj_class = yolo_data[0]  # Lớp đối tượng (class)
    x_center = float(yolo_data[1])
    y_center = float(yolo_data[2])
    width = float(yolo_data[3])
    height = float(yolo_data[4])

    # Chuyển từ YOLO sang tọa độ góc
    x_min = (x_center - width / 2) * img_width
    x_max = (x_center + width / 2) * img_width
    y_min = (y_center - height / 2) * img_height
    y_max = (y_center + height / 2) * img_height

    return obj_class, x_min, y_min, x_max, y_max


if __name__ == "__main__":
    # Convert bbox to Yolo và ngược lại:
    x_min = 50
    y_min = 100
    x_max = 200
    y_max = 300
    img_width = 640
    img_height = 480
    obj_class = 0

    yolo_str = xyxy_to_yolo_str(
        x_min, y_min, x_max, y_max, img_width, img_height, obj_class
    )
    print(yolo_str)  # "0 0.195312 0.416667 0.234375 0.416667"

    yolo_str = "0 0.195312 0.416667 0.234375 0.416667"
    img_width = 640
    img_height = 480

    obj_class, x_min, y_min, x_max, y_max = yolo_str_to_xyxy(
        yolo_str, img_width, img_height
    )
    print(obj_class, x_min, y_min, x_max, y_max)  # 0 50.0 100.0 200.0 300.0



"""
ntanh

An python parametters library.
"""

__version__ = "0.1.6"
__author__ = "Nguyễn Tuấn Anh - nt.anh.fai@gmail.com"
__credits__ = "MIT License"

from ntanh.yolo_boxes import xyxy_to_yolo_str, yolo_str_to_xyxy
from . import ParamsBase

__help__ = """
from ntanh.ParamsBase import tactParametters
from ntanh.yolo_boxes import xyxy_to_yolo_str, yolo_str_to_xyxy
"""


def info():
    print(
        """
          # Giới thiệu

ntanh là một thư viện các nhiệm vụ hàng ngày sử dụng, hay dùng nhưng không khó, mất thời gian code cho các dự án lẻ tẻ.

# Cài đặt
`pip install ntanh`

# Cách dùng:

```python
from pprint import pprint
from ntanh.ParamsBase import tactParametters
import ntanh

print(ntanh.__version__)
mParams = tactParametters()

fns = mParams.fnFIS(r"../", exts=(".py"))
pprint(fns)
```

Kết quả:

```
'0.1.4'
['../tact/setup.py',
 '../tact/__init__.py',
 '../tact/build/lib/ntanh/ParamsBase.py',
 '../tact/build/lib/ntanh/__init__.py',
 '../tact/build/lib/tact/ParamsBase.py',
 '../tact/build/lib/tact/__init__.py',
 '../tact/dev/test_tact.py',
 '../tact/ntanh/ParamsBase.py',
 '../tact/ntanh/__init__.py']
```

Ví dụ 2: tạo file tham số:

```python

from pprint import pprint
from ntanh.ParamsBase import tactParametters

class Parameters(tactParametters):
    def __init__(self, ModuleName="TACT"):
        super().__init__()
        self.thamso1 = "thamso1"
        self.thamso2 = " xâu tiếng việt"
        self.api_url = "https://200.168.90.38:6699/avi/collect_data"
        self.testpath = "D:/test_debug_fii"
        self.test_real = 0.8
        self.test_int = 12
        self.test_dict = {
            1: 2,
            3: 4.5,
            "6": "bảy nhá",
            -1: "Tám",
            9: [10, 11.2, "22", (33, 44, "55")],
            10: {101: 12, 102: "mười ba"},
        }
        self.test_list = [1, 2, 3, 4, 5, 6, 7, 8, 9]

        self.load_then_save_to_yaml(file_path="configs_test.yml", ModuleName=ModuleName)
        self.privateVar1 = 2
        self.privateVar2 = "Not in param file"


mParams = Parameters(ModuleName="test")

pprint(mParams.__dict__)
```

Kết quả:

```
{'ModuleName': 'test',
 'api_url': 'https://200.168.90.38:6699/avi/collect_data',
 'fn': 'configs_test.yml',
 'logdir': '',
 'privateVar1': 2,
 'privateVar2': 'Not in param file',
 'test_dict': {-1: 'Tám',
               1: 2,
               3: 4.5,
               9: [10, 11.2, '22', (33, 44, '55')],
               10: {101: 12, 102: 'mười ba'},
               '6': 'bảy nhá'},
 'test_int': 12,
 'test_list': [1, 2, 3, 4, 5, 6, 7, 8, 9],
 'test_real': 0.8,
 'testpath': 'D:/test_debug_fii',
 'thamso1': 'thamso1',
 'thamso2': ' xâu tiếng việt'}
```



          """
    )
